==> foundation-ui-components-1.15.0.tgz: package/src/common/accordion/specs/NsAccordionHeader.spec.tsx <==
import React from 'react';
import { render, fireEvent } from '@/test-utils/index';
import { NsAccordionHeader, AccordionVariant } from '@/common/index';

describe('NsAccordionHeader', () => {
    it('1. renders title correctly', () => {
        const onClick = jest.fn();
        const title = 'Section Header';
        const { getByText } = render(
            <NsAccordionHeader
                variant={AccordionVariant.Basic}
                title={title}
                onClick={onClick}
                invert={false}
                isOpen={true}
            />
        );
        const el = getByText(title);
        expect(el).toBeInTheDocument();
        expect(el.closest('header')).toHaveAttribute('aria-expanded', 'true');
    });
    it('2. renders title correctly', () => {
        const onClick = jest.fn();
        const title = 'Section Header';
        const { getByText } = render(
            <NsAccordionHeader
                variant={AccordionVariant.Compact}
                title={<span>{title}</span>}
                onClick={onClick}
                invert={false}
                isOpen={false}
            />
        );
        const el = getByText(title);
        expect(el).toBeInTheDocument();
        expect(el.closest('header')).toHaveAttribute('aria-expanded', 'false');
    });
    it('3. calls onClick handler when clicked', () => {
        const onClick = jest.fn();
        const { container } = render(
            <NsAccordionHeader
                variant={AccordionVariant.Basic}
                title="Section Header"
                onClick={onClick}
                invert={false}
                isOpen={false}
            />
        );
        const header = container.querySelector('header');
        if (header) {
            fireEvent.click(header);
            expect(onClick).toHaveBeenCalledTimes(1);
        }
    });

    it('4. renders with additional class name', () => {
        const additionalClassName = 'custom-class';
        const onClick = jest.fn();
        const { container } = render(
            <NsAccordionHeader
                isOpen={false}
                variant={AccordionVariant.Basic}
                title="Section Header"
                additionalProps={{ className: additionalClassName }}
                onClick={onClick}
                invert={false}
            />
        );
        expect(container.querySelector('header')).toHaveClass(`section-header ${additionalClassName}`);
    });

    it('5. renders with expanded class when isOpen is true', () => {
        const onClick = jest.fn();
        const { container } = render(
            <NsAccordionHeader
                variant={AccordionVariant.Basic}
                title="Section Header"
                isOpen
                onClick={onClick}
                invert={false}
            />
        );
        expect(container.querySelector('header')).toHaveClass('expanded');
    });

    it('6. renders with header icon', () => {
        const onClick = jest.fn();
        const { getByTestId } = render(
            <NsAccordionHeader
                variant={AccordionVariant.Basic}
                title="Section Header"
                onClick={onClick}
                invert={false}
                isOpen
            />
        );
        // this icon refers to end icon which is either arrowUp or arrowDown
        expect(getByTestId('icon')).toBeInTheDocument();
    });
    it('7. renders with custom start icon', () => {
        const onClick = jest.fn();
        const { getByTestId } = render(
            <NsAccordionHeader
                variant={AccordionVariant.Basic}
                title="Section Header"
                onClick={onClick}
                invert={false}
                isOpen
                startIcon={{ name: 'hamburgerIcon', testId: 'hamburger-test' }}
            />
        );
        expect(getByTestId('hamburger-test')).toBeInTheDocument();
    });
    it('8. does not render start icon, when invalid icon name is passed', () => {
        const onClick = jest.fn();
        const invalidIconName = 'hambur';
        const testId = 'hamburger-test';
        const { queryByTestId } = render(
            <NsAccordionHeader
                variant={AccordionVariant.Basic}
                title="Section Header"
                onClick={onClick}
                invert={false}
                isOpen
                startIcon={{ name: invalidIconName as any, testId }}
            />
        );
        expect(queryByTestId(testId)).toBeNull();
    });
});

==> foundation-ui-components-1.22.1.tgz: package/src/common/accordion/specs/NsAccordionHeader.spec.tsx <==
import React from 'react';
import { render, fireEvent } from '@/test-utils/index';
import { NsAccordionHeader, AccordionVariant } from '@/common/index';

describe('NsAccordionHeader', () => {
    it('1. renders title correctly', () => {
        const onClick = jest.fn();
        const title = 'Section Header';
        const { getByText } = render(
            <NsAccordionHeader
                variant={AccordionVariant.Basic}
                title={title}
                onClick={onClick}
                invert={false}
                isOpen={true}
            />
        );
        const el = getByText(title);
        expect(el).toBeInTheDocument();
        expect(el.closest('header')).toHaveAttribute('aria-expanded', 'true');
    });
    it('2. renders title correctly', () => {
        const onClick = jest.fn();
        const title = 'Section Header';
        const { getByText } = render(
            <NsAccordionHeader
                variant={AccordionVariant.Compact}
                title={<span>{title}</span>}
                onClick={onClick}
                invert={false}
                isOpen={false}
            />
        );
        const el = getByText(title);
        expect(el).toBeInTheDocument();
        expect(el.closest('header')).toHaveAttribute('aria-expanded', 'false');
    });
    it('3. calls onClick handler when clicked', () => {
        const onClick = jest.fn();
        const { container } = render(
            <NsAccordionHeader
                variant={AccordionVariant.Basic}
                title="Section Header"
                onClick={onClick}
                invert={false}
                isOpen={false}
            />
        );
        const header = container.querySelector('header');
        if (header) {
            fireEvent.click(header);
            expect(onClick).toHaveBeenCalledTimes(1);
        }
    });

    it('4. renders with additional class name', () => {
        const additionalClassName = 'custom-class';
        const onClick = jest.fn();
        const { container } = render(
            <NsAccordionHeader
                isOpen={false}
                variant={AccordionVariant.Basic}
                title="Section Header"
                additionalProps={{ className: additionalClassName }}
                onClick={onClick}
                invert={false}
            />
        );
        expect(container.querySelector('header')).toHaveClass(`section-header ${additionalClassName}`);
    });

    it('5. renders with expanded class when isOpen is true', () => {
        const onClick = jest.fn();
        const { container } = render(
            <NsAccordionHeader
                variant={AccordionVariant.Basic}
                title="Section Header"
                isOpen
                onClick={onClick}
                invert={false}
            />
        );
        expect(container.querySelector('header')).toHaveClass('expanded');
    });

    it('6. renders with header icon when showEndIconWhenEmpty is true', () => {
        const onClick = jest.fn();
        const { getByTestId } = render(
            <NsAccordionHeader
                variant={AccordionVariant.Basic}
                title="Section Header"
                onClick={onClick}
                invert={false}
                isOpen
                showEndIconWhenEmpty={true}
            />
        );
        // this icon refers to end icon which is either arrowUp or arrowDown
        expect(getByTestId('icon')).toBeInTheDocument();
    });
    it('7. renders with custom start icon', () => {
        const onClick = jest.fn();
        const { getByTestId } = render(
            <NsAccordionHeader
                variant={AccordionVariant.Basic}
                title="Section Header"
                onClick={onClick}
                invert={false}
                isOpen
                startIcon={{ name: 'hamburgerIcon', testId: 'hamburger-test' }}
            />
        );
        expect(getByTestId('hamburger-test')).toBeInTheDocument();
    });
    it('8. does not render start icon, when invalid icon name is passed', () => {
        const onClick = jest.fn();
        const invalidIconName = 'hambur';
        const testId = 'hamburger-test';
        const { queryByTestId } = render(
            <NsAccordionHeader
                variant={AccordionVariant.Basic}
                title="Section Header"
                onClick={onClick}
                invert={false}
                isOpen
                startIcon={{ name: invalidIconName as any, testId }}
            />
        );
        expect(queryByTestId(testId)).toBeNull();
    });
});
